==> arg-services-1.1.0-sources.jar: de/uni_trier/recap/arg_services/cbr/v1beta/RetrievalServiceGrpc.java <==
package de.uni_trier.recap.arg_services.cbr.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.52.1)",
    comments = "Source: arg_services/cbr/v1beta/retrieval.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class RetrievalServiceGrpc {

  private RetrievalServiceGrpc() {}

  public static final String SERVICE_NAME = "arg_services.cbr.v1beta.RetrievalService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest,
      de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse> getRetrieveMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Retrieve",
      requestType = de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest.class,
      responseType = de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest,
      de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse> getRetrieveMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest, de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse> getRetrieveMethod;
    if ((getRetrieveMethod = RetrievalServiceGrpc.getRetrieveMethod) == null) {
      synchronized (RetrievalServiceGrpc.class) {
        if ((getRetrieveMethod = RetrievalServiceGrpc.getRetrieveMethod) == null) {
          RetrievalServiceGrpc.getRetrieveMethod = getRetrieveMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest, de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Retrieve"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse.getDefaultInstance()))
              .setSchemaDescriptor(new RetrievalServiceMethodDescriptorSupplier("Retrieve"))
              .build();
        }
      }
    }
    return getRetrieveMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static RetrievalServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<RetrievalServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<RetrievalServiceStub>() {
        @java.lang.Override
        public RetrievalServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new RetrievalServiceStub(channel, callOptions);
        }
      };
    return RetrievalServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static RetrievalServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<RetrievalServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<RetrievalServiceBlockingStub>() {
        @java.lang.Override
        public RetrievalServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new RetrievalServiceBlockingStub(channel, callOptions);
        }
      };
    return RetrievalServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static RetrievalServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<RetrievalServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<RetrievalServiceFutureStub>() {
        @java.lang.Override
        public RetrievalServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new RetrievalServiceFutureStub(channel, callOptions);
        }
      };
    return RetrievalServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class RetrievalServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void retrieve(de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getRetrieveMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getRetrieveMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest,
                de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse>(
                  this, METHODID_RETRIEVE)))
          .build();
    }
  }

  /**
   */
  public static final class RetrievalServiceStub extends io.grpc.stub.AbstractAsyncStub<RetrievalServiceStub> {
    private RetrievalServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected RetrievalServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new RetrievalServiceStub(channel, callOptions);
    }

    /**
     */
    public void retrieve(de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getRetrieveMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class RetrievalServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<RetrievalServiceBlockingStub> {
    private RetrievalServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected RetrievalServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new RetrievalServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse retrieve(de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getRetrieveMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class RetrievalServiceFutureStub extends io.grpc.stub.AbstractFutureStub<RetrievalServiceFutureStub> {
    private RetrievalServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected RetrievalServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new RetrievalServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse> retrieve(
        de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getRetrieveMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_RETRIEVE = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final RetrievalServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(RetrievalServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_RETRIEVE:
          serviceImpl.retrieve((de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class RetrievalServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    RetrievalServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.cbr.v1beta.RetrievalProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("RetrievalService");
    }
  }

  private static final class RetrievalServiceFileDescriptorSupplier
      extends RetrievalServiceBaseDescriptorSupplier {
    RetrievalServiceFileDescriptorSupplier() {}
  }

  private static final class RetrievalServiceMethodDescriptorSupplier
      extends RetrievalServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    RetrievalServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (RetrievalServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new RetrievalServiceFileDescriptorSupplier())
              .addMethod(getRetrieveMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> arg-services-1.5.9-sources.jar: de/uni_trier/recap/arg_services/cbr/v1beta/RetrievalServiceGrpc.java <==
package de.uni_trier.recap.arg_services.cbr.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.71.0)",
    comments = "Source: arg_services/cbr/v1beta/retrieval.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class RetrievalServiceGrpc {

  private RetrievalServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "arg_services.cbr.v1beta.RetrievalService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest,
      de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse> getRetrieveMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Retrieve",
      requestType = de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest.class,
      responseType = de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest,
      de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse> getRetrieveMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest, de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse> getRetrieveMethod;
    if ((getRetrieveMethod = RetrievalServiceGrpc.getRetrieveMethod) == null) {
      synchronized (RetrievalServiceGrpc.class) {
        if ((getRetrieveMethod = RetrievalServiceGrpc.getRetrieveMethod) == null) {
          RetrievalServiceGrpc.getRetrieveMethod = getRetrieveMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest, de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Retrieve"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse.getDefaultInstance()))
              .setSchemaDescriptor(new RetrievalServiceMethodDescriptorSupplier("Retrieve"))
              .build();
        }
      }
    }
    return getRetrieveMethod;
  }

  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesRequest,
      de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesResponse> getSimilaritiesMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Similarities",
      requestType = de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesRequest.class,
      responseType = de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesRequest,
      de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesResponse> getSimilaritiesMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesRequest, de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesResponse> getSimilaritiesMethod;
    if ((getSimilaritiesMethod = RetrievalServiceGrpc.getSimilaritiesMethod) == null) {
      synchronized (RetrievalServiceGrpc.class) {
        if ((getSimilaritiesMethod = RetrievalServiceGrpc.getSimilaritiesMethod) == null) {
          RetrievalServiceGrpc.getSimilaritiesMethod = getSimilaritiesMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesRequest, de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Similarities"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesResponse.getDefaultInstance()))
              .setSchemaDescriptor(new RetrievalServiceMethodDescriptorSupplier("Similarities"))
              .build();
        }
      }
    }
    return getSimilaritiesMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static RetrievalServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<RetrievalServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<RetrievalServiceStub>() {
        @java.lang.Override
        public RetrievalServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new RetrievalServiceStub(channel, callOptions);
        }
      };
    return RetrievalServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports all types of calls on the service
   */
  public static RetrievalServiceBlockingV2Stub newBlockingV2Stub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<RetrievalServiceBlockingV2Stub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<RetrievalServiceBlockingV2Stub>() {
        @java.lang.Override
        public RetrievalServiceBlockingV2Stub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new RetrievalServiceBlockingV2Stub(channel, callOptions);
        }
      };
    return RetrievalServiceBlockingV2Stub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static RetrievalServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<RetrievalServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<RetrievalServiceBlockingStub>() {
        @java.lang.Override
        public RetrievalServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new RetrievalServiceBlockingStub(channel, callOptions);
        }
      };
    return RetrievalServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static RetrievalServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<RetrievalServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<RetrievalServiceFutureStub>() {
        @java.lang.Override
        public RetrievalServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new RetrievalServiceFutureStub(channel, callOptions);
        }
      };
    return RetrievalServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void retrieve(de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getRetrieveMethod(), responseObserver);
    }

    /**
     */
    default void similarities(de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getSimilaritiesMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service RetrievalService.
   */
  public static abstract class RetrievalServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return RetrievalServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service RetrievalService.
   */
  public static final class RetrievalServiceStub
      extends io.grpc.stub.AbstractAsyncStub<RetrievalServiceStub> {
    private RetrievalServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected RetrievalServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new RetrievalServiceStub(channel, callOptions);
    }

    /**
     */
    public void retrieve(de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getRetrieveMethod(), getCallOptions()), request, responseObserver);
    }

    /**
     */
    public void similarities(de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getSimilaritiesMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service RetrievalService.
   */
  public static final class RetrievalServiceBlockingV2Stub
      extends io.grpc.stub.AbstractBlockingStub<RetrievalServiceBlockingV2Stub> {
    private RetrievalServiceBlockingV2Stub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected RetrievalServiceBlockingV2Stub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new RetrievalServiceBlockingV2Stub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse retrieve(de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getRetrieveMethod(), getCallOptions(), request);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesResponse similarities(de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getSimilaritiesMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do limited synchronous rpc calls to service RetrievalService.
   */
  public static final class RetrievalServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<RetrievalServiceBlockingStub> {
    private RetrievalServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected RetrievalServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new RetrievalServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse retrieve(de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getRetrieveMethod(), getCallOptions(), request);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesResponse similarities(de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getSimilaritiesMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service RetrievalService.
   */
  public static final class RetrievalServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<RetrievalServiceFutureStub> {
    private RetrievalServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected RetrievalServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new RetrievalServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse> retrieve(
        de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getRetrieveMethod(), getCallOptions()), request);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesResponse> similarities(
        de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getSimilaritiesMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_RETRIEVE = 0;
  private static final int METHODID_SIMILARITIES = 1;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_RETRIEVE:
          serviceImpl.retrieve((de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse>) responseObserver);
          break;
        case METHODID_SIMILARITIES:
          serviceImpl.similarities((de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getRetrieveMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveRequest,
              de.uni_trier.recap.arg_services.cbr.v1beta.RetrieveResponse>(
                service, METHODID_RETRIEVE)))
        .addMethod(
          getSimilaritiesMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesRequest,
              de.uni_trier.recap.arg_services.cbr.v1beta.SimilaritiesResponse>(
                service, METHODID_SIMILARITIES)))
        .build();
  }

  private static abstract class RetrievalServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    RetrievalServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.cbr.v1beta.RetrievalProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("RetrievalService");
    }
  }

  private static final class RetrievalServiceFileDescriptorSupplier
      extends RetrievalServiceBaseDescriptorSupplier {
    RetrievalServiceFileDescriptorSupplier() {}
  }

  private static final class RetrievalServiceMethodDescriptorSupplier
      extends RetrievalServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    RetrievalServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (RetrievalServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new RetrievalServiceFileDescriptorSupplier())
              .addMethod(getRetrieveMethod())
              .addMethod(getSimilaritiesMethod())
              .build();
        }
      }
    }
    return result;
  }
}
